<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
    xmlns:xalan="http://xml.apache.org/xalan" 
    xmlns:pepper="http://www.pepper.com/elements" 
    extension-element-prefixes="pepper">
    
    <xalan:component prefix="pepper">
        <xalan:script lang="javaclass" src="com.pepper.script.Elements"/>
    </xalan:component>

    <xsl:output method="html" encoding ="utf-8" />
    
    <!-- define the parameters passed by the framework into this XSL stylesheet -->
    <xsl:param name="packageId" />
    <xsl:param name="platform" />
    <xsl:param name="design" />
        
    <!-- Match the root element of the Page data to begin the transformation -->    
    <xsl:template match="/">
        <!--Create the HTML header -->
        <html xmlns="http://www.w3.org/1999/xhtml">
            <head>
                <title>Worlds</title>
                <meta http-equiv="Content-Type" content="text/html; charset=utf-8" ></meta>
                <!-- add link to the framework main CSS stylesheet -->
                <link href="{$platform}/resources/styles/styles.css" rel="stylesheet" type="text/css" />
                <!-- add link to a user-defined CSS stylesheet -->
                <link href="{$design}/design/myStyles.css" rel="stylesheet" type="text/css" />
                <!-- initialize the Javascript-to-framework bridge -->
                <pepper:initscriptbridge package="{$packageId}" />
                <!-- add link to user-defined file containing javascript -->
                <script language="JavaScript" type="text/javascript" src="{$design}/design/helloWorld.js"/>
            </head>
            
            <!-- create the HTML body -->
            <body>
            
                <!--create the page toolbar -->
                <pepper:pagebar class="PageBar" id="pb-{$packageId}" package="{$packageId}">
                    <!-- create three toolbar buttons -->
                    <pepper:pagebarentry key="PageBar.New" action="NewPage" param="world" />
                    <pepper:pagebarentry key="PageBar.Edit" script="showSelectedPage()" />
                    <pepper:pagebarentry key="PageBar.Delete" script="deleteSelectedWorld()"  />
                </pepper:pagebar>
                
                <!--create a div with class myPage to contain and position all page contents -->
                <div class="myPage">
                
                    <!-- Display message -->
                    <div class="myFirstStyle">Existing Worlds</div>
                    
                    <!-- add some white space with user-defined CSS class -->
                    <p class="verticalSpacer20" />
                    
                    <!-- create form to enclose elements with user input -->
                    <form name="worlds" >
                        <!-- create a table to hold labels and input elements -->
                        <table border="1">
                            <!-- display the table header row -->
                            <tr>
                                <td></td>
                                <!-- get the text for the table header row -->
                                <td class="Label"><pepper:textString package="{$packageId}" key="Label.Name"/></td>
                            </tr>
                            <!-- Iterate through world Page instances and apply xsl templates -->  
                            <xsl:for-each select="section/page[@type='world']">
                                <xsl:apply-templates />
                            </xsl:for-each>
                        </table>
                    </form>
                </div>
            </body>
        </html>
    </xsl:template>

    <xsl:template match="worldName">
        <!-- worldName elements appear in the XML file through caching rules -->
        <!-- for each worldName element, output a table row -->
        <tr>
            <!-- output a radio button so user can select this world for editing 
                The value attribute is assigned the value of worldName's parent 
                elelment's id attribute, which specifies the world Page. 
                The parent element is a <page> -->
            <td>
                <input type="radio" name="worldPicker" value="{../@id}" />
            </td>
            <td>
                <!--output the worldName element's text -->
                <xsl:value-of select="."/>
            </td>
        </tr>
    </xsl:template>
</xsl:stylesheet>