<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
    xmlns:xalan="http://xml.apache.org/xalan"
    xmlns:pepper="http://www.pepper.com/elements"
    extension-element-prefixes="pepper">
    
    <xalan:component prefix="pepper">
        <xalan:script lang="javaclass" src="com.pepper.script.Elements"/>
    </xalan:component>
    
    <xsl:output method="html" encoding ="utf-8" />
    
    <!-- define the parameters passed by the framework into this XSL stylesheet -->
    <xsl:param name="packageId" />
    <xsl:param name="platform" />
    <xsl:param name="design" />
    
    <!-- Match the root element of the Page data to begin the transformation -->    
    <xsl:template match="/">
        <html xmlns="http://www.w3.org/1999/xhtml">
            <head>
                <!-- set <title> from world Page's <worldName> element -->
                <title><xsl:value-of select="pepper:nameString($packageId,/page/worldName)"/></title>
                <meta http-equiv="Content-Type" content="text/html; charset=utf-8" ></meta>
                <!-- add link to the framework main CSS stylesheet -->
                <link href="{$platform}/resources/styles/styles.css" rel="stylesheet" type="text/css" />
                <!-- add link to a user-defined CSS stylesheet -->
                <link href="{$design}/design/myStyles.css" rel="stylesheet" type="text/css" />
                <!-- initialize the Javascript-to-framework bridge -->
                <pepper:initscriptbridge package="{$packageId}" />
            </head>
            <!-- create the HTML body -->
            <body>
                <!--Create page toolbar -->
                <pepper:pagebar class="PageBar" id="pb-{$packageId}" package="{$packageId}">
                    <!-- create one toolbar button -->
                    <pepper:pagebarentry key="PageBar.Done" action="ShowTabContents" />
                </pepper:pagebar>
                
                <!--create a div with class myPage to contain and position all page contents -->
                <div class="myPage">
                
                    <!-- Display message -->
                    <div class="myFirstStyle">Create or Edit a World</div>
                    <!-- add some white space with user-defined CSS class -->
                    <p class="verticalSpacer20" />
                        <!-- create required form to enclose elements with user input -->
                        <!-- NOTE: when user input is to be saved in XML instance files
                             the input elements MUST be enclosed in a <form> -->
                    <form>
                        <!-- create a table to contain labels and input fields for world -->
                        <table>
                            <tr>
                                <td class="Label">
                                  <!-- add a label to the first cell in the row -->
                                    <pepper:textString package="{$packageId}" key="Label.Name"/>:
                                </td>
                                <!--create a series of input text fields with the required value and xpath
                                  attributes that are necessary when displaying (value="{anXpath}") and saving 
                                  (xpath="anXpath") user-entered data inXML instance files -->
                                <td>
                                    <input type="text" id="worldName" class="Field" style="width:400px" value="{/page/worldName}" xpath="/page/worldName" />
                                </td>
                            </tr> 
                            <tr>
                                <td class="Label">
                                    <pepper:textString package="{$packageId}" key="Label.Radius" />:
                                </td>
                                <td>
                                    <input type="text" id="worldRadius" class="Field" style="width:400px" value="{/page/worldRadius}" xpath="/page/worldRadius" />
                                </td>
                            </tr> 
                            <tr>
                                <td class="Label">
                                    <pepper:textString package="{$packageId}" key="Label.YearLength"/>:
                                </td>
                                <td align="left">
                                    <input type="text" id="yearLength" value="{/page/yearLength}" xpath="/page/yearLength" />
                                </td>
                            </tr>
                            <tr>
                                <td class="Label">
                                    <pepper:textString package="{$packageId}" key="Label.DayLength"/>:
                                </td>
                                <td align="left">
                                    <input type="text" id="dayLength" value="{/page/dayLength}" xpath="/page/dayLength" />
                                </td>
                            </tr>
                            <tr>
                                <td class="Label">
                                    <pepper:textString package="{$packageId}" key="Label.DistanceFromSun"/>:
                                </td>
                                <td align="left">
                                    <input type="text" id="distanceFromSun" value="{/page/distanceFromSun}" xpath="/page/distanceFromSun" />
                                </td>
                            </tr>
                            <tr>
                                <td class="Label">
                                    <pepper:textString package="{$packageId}" key="Label.HasWater" />:
                                </td>
                                <!--create a series of input checkboxes with the required value and xpath
                                    attributes that are necessary when saving user-entered data into
                                    XML intsance files. When the box is checked, "true" is saved, else "false" -->
                                <td align="left">
                                    <pepper:checkbox  type="checkbox" id="hasWater" value="{/page/hasWater}" xpath="/page/hasWater" />
                                </td>
                            </tr>                          
                            <tr>
                                <td class="Label">
                                    <pepper:textString package="{$packageId}" key="Label.HasLife"/>:
                                </td>
                                <td align="left">
                                    <pepper:checkbox  type="checkbox" id="hasLife" value="{/page/hasLife}" xpath="/page/hasLife" />
                                </td>
                            </tr>
                            <tr>
                                <td class="Label">
                                    <pepper:textString package="{$packageId}" key="Label.PlanVisit"/>:
                                </td>
                                <td align="left">
                                    <!-- create three pepper:radiobuttons to store user selection -->
                                    <span class="Label">Now: </span>
                                    <pepper:radiobutton id="planVisit" xpath="/page/planVisit" storedvalue="{/page/planVisit}" value="1" class="Text"/>
                                    <span class="Label">Soon: </span>
                                    <pepper:radiobutton id="planVisit" xpath="/page/planVisit" storedvalue="{/page/planVisit}" value="2" class="Text"/>
                                    <span class="Label">Never: </span>
                                    <pepper:radiobutton id="planVisit" xpath="/page/planVisit" storedvalue="{/page/planVisit}" value="3" class="Text"/>
                                </td>
                            </tr>
                        </table>
                    </form>
                </div>
            </body>
        </html>
    </xsl:template>
</xsl:stylesheet>