/*
 * Copyright 2004-2006, Pepper Computer, Inc.  All rights reserved.
 * PEPPER PROPRIETARY/CONFIDENTIAL.  Use is subject to license terms.
 */
package com.pepper.HW;

import java.awt.BorderLayout;
import java.awt.GridLayout;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.awt.Dimension;
import java.awt.ComponentOrientation;

import java.util.Properties;

import javax.swing.AbstractAction;
import javax.swing.JPanel;
import javax.swing.JLabel;
import javax.swing.JTextField;
import javax.swing.JButton;
import javax.swing.Box;
import javax.swing.BoxLayout;

import com.pepper.platform.program.AbstractPepperProgram;
import com.pepper.platform.program.JavaSectionComponent;
import com.pepper.guiutils.ToolBar;
import com.pepper.guiutils.ToolBarButton;

//imports required for writing to the Keeper log
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * <p>A Pepper Keeper framework Java Section that demonstrates adding a ToolBar 
 * and ToolBarButtons, all of which obtain visual styling from keeper.css, and writing 
 * to the Keeper log and to the Status Bar.
 * <p>Note; All Pepper framework Java Sections must extend <code>JPanel</code>.</p>
 * <p><code>implementing JavaSectionComponent</code> requires overiding 
 * <code>initComponent</code>, which provides access to the application's main
 * class and framework parameters.</p>
 *
 */
public class LogStatusbarJavaSection extends JPanel implements JavaSectionComponent {
    
    /** Toolbar for Section*/
    protected ToolBar toolbar = new ToolBar();
    
    /** JPanel to hold toolbar and content */
    protected JPanel base = new JPanel();
    
    /** JPanel to hold all content  */
    protected JPanel panel_content = new JPanel();
    
    /** JPanel to hold labels and text fields */
    protected JPanel panel_textFields = new JPanel();
    
    /** GUI Wigdet */
    protected JLabel lbl_getText = new JLabel("Enter text: ", JLabel.RIGHT);
    
    /** GUI Wigdet */
    protected JLabel lbl_result = new JLabel("Result: ", JLabel.RIGHT);
    
    /** GUI Wigdet */
    protected JTextField txt_getThis = new JTextField();
    
    /** GUI Wigdet */
    protected JTextField txt_result = new JTextField();
    
    /** Button to clear text fields */
    protected JButton btn_clear = new JButton("Clear");
    
    /** Handle for acessing <code>HelloWorld</code>, the application's base class. */
    public HelloWorld helloWorld;
    
    /** Log instance for writing to Keeper log */
    static Log log = LogFactory.getLog("com.pepper.HW");
    
    /**
     * Empty Constructor
     */
    public LogStatusbarJavaSection() {
    }
    
    /**
     * Required method override for classes that implement the
     * <code>JavaSectionComponent</code> interface that is used here to create a
     * local reference to <code>HelloWorld</code> in order to use its
     * getGSP().writeSstatus() method to write to the Keeper Status Bar.
     *
     * @param theProg is the AbstractPepperProgram passed automatically by the
     * framework
     * @param params is a Properties object containing framework parameters
     * passes automatically by the framework
     */
    public void initComponent(AbstractPepperProgram theProg, Properties params) {
        //get local reference to HelloWorld in order to write to the status bar
        helloWorld = (HelloWorld) theProg;
        
        //initialize the section components here, after getting reference to program main class (theProg).
        initMe();
    }
    
    /**
     * Initializes the Section.
     */
    private void initMe() {
        //create three action objects
        WriteToLogAction writeLog = new WriteToLogAction();
        WriteToStatusBarAction writeStatus = new WriteToStatusBarAction();
        ClearButtonAction clearFields = new ClearButtonAction();
        
        ToolBarButton b1 = new ToolBarButton(writeLog, "Write To Log");
        ToolBarButton b2 = new ToolBarButton(writeStatus, "Write To Status Bar");
        
        toolbar.addButton(b1);
        toolbar.addButton(b2);
        
        txt_getThis.setPreferredSize(new Dimension(190, 24));
        
        txt_result.setPreferredSize(new Dimension(190, 24));
        txt_result.setBackground(base.getBackground());
        
        btn_clear.addActionListener(clearFields);
        
        panel_textFields.setLayout(new GridLayout(0,2));
        panel_textFields.setComponentOrientation(ComponentOrientation.LEFT_TO_RIGHT);
        
        panel_textFields.add(lbl_getText);
        panel_textFields.add(txt_getThis);
        panel_textFields.add(Box.createVerticalStrut(5));
        panel_textFields.add(Box.createVerticalStrut(5));
        panel_textFields.add(lbl_result);
        panel_textFields.add(txt_result);
        
        panel_content.setLayout(new BoxLayout(panel_content, BoxLayout.Y_AXIS));
        
        panel_content.add(Box.createVerticalStrut(25));
        panel_content.add(panel_textFields);
        panel_content.add(Box.createVerticalStrut(25));
        btn_clear.setPreferredSize(new Dimension(100,25));
        panel_content.add(btn_clear);
        
        base.add(panel_content, BorderLayout.WEST);
        
        this.setLayout(new BorderLayout());
        this.add(toolbar, BorderLayout.NORTH);
        this.add(base, BorderLayout.WEST);
    }
    
    /**
     * <p>Action class that writes to the Keeper log.</p>
     */
    protected class WriteToLogAction extends AbstractAction {
        public void actionPerformed(ActionEvent ev) {
            
            try {
                log.info(txt_getThis.getText());
                txt_result.setText("Text written to log");
            } catch (Exception e) {
                txt_result.setText("Write to log failed");
            }
        }
    }
    
    /**
     * <p>Action class that writes to the Keeper Status Bar.</p>
     */
    protected class WriteToStatusBarAction extends AbstractAction {
        public void actionPerformed(ActionEvent ev) {
            try {
                txt_result.setText("Text written to Status Bar");
            helloWorld.getGSP().writeStatus(txt_getThis.getText());
            } catch (Exception e) {
                txt_result.setText("Write to Status bar failed");
            }
        }
    }
    
    /**
     * <p>Action class that clears text fields.</p>
     */
    protected class ClearButtonAction extends AbstractAction {
        public void actionPerformed(ActionEvent ev) {
            String str = new String();
            txt_getThis.setText(str);
            txt_result.setText(str);
        }
    }
}
