/*
 * Copyright (c) 2006 Pepper Computer, Inc. All Rights Reserved.
 * PEPPER PROPRIETARY/CONFIDENTIAL.  Use is subject to license terms.
 */
package com.pepper.HW;

import com.pepper.platform.program.AbstractPepperProgram;
import com.pepper.platform.program.PepperProgramConfig;
import com.pepper.platform.program.PepperProgramException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 *
 * <p>Base class of the Hello World application for the Pepper SDK.</p>
 * <p>Extends AbstractPepperProgram as every application base class must.</p>
*/
public class HelloWorld extends AbstractPepperProgram {
    
    /**
     * <p>Constant used to register EditJava Action.</p>
     */
    public static final String EDIT_JAVA_ACTION = "EditJavaAction";
    
    /**
     * <p>Constant used to register DoneJavaAction.</p>
     */
    public static final String DONE_JAVA_ACTION = "DoneJavaAction";
    
    /**
     * <p>Holds the <code>WorldJavaSection</code> object, which displays and
     * allows user to edit each world's data items.</p>
     * <p>Having a local reference to the <code>WorldJavaSection</code> object
     * enables other classes, such as the DoneJava and EditJava classes,
     * to access it.</p>
     */
    public WorldJavaSection worldJavaSection;
    
    /**
     * <p>The Log instance, as required for every class that is to
     * write to the Keeper log file.</p>
     */
    static Log log = LogFactory.getLog("com.pepper.HW");
    
    /**
     * <p><code>HelloWorld</code> constructor, which calls <code>super(pid)
     * </code> as required by every base class</p>
     *
     * @param pid the process ID passed to this base class by the framework
     */
    public HelloWorld(Integer pid) {
        super(pid);
    }
    
    /**
     * <p>Required method override that registers Actions, if any, with the
     * framework.</p>
     * <code>init()</code> must be overridden in every AbstractPepperProgram base
     * class and must throw a <code>PepperProgramException</code>. Example of
     * Actions registration::<br>
     * <code>registerAction(EDIT_JAVA, new EditJavaAction());</code>
     *
     * @param config is a required parameter passed by the framework and passed
     * to the parent classes <code>init()</code> method, as shown here.
    */
    public void init(PepperProgramConfig config) throws PepperProgramException {
        super.init(config);
        
        //Register application's Actions with framework
        registerAction(EDIT_JAVA_ACTION, new EditJavaAction());
        log.info("completed EditJavaAction action registration");
        registerAction(DONE_JAVA_ACTION, new DoneJavaAction());
        log.info("completed DoneJavaAction action registration");
    }
    
    /**
     * <p>Registers the <code>WorldJavaSection</code> object with the HelloWorld
     * base class. This enables other class objects, such as the DoneJavaAction and
     * EditJavaAction, to access the <code>WorldJavaSection</code> object.
     * @param s is the <code>WorldJavaSection</code> object passed for
     * registration to <code>HelloWorld</code>.</p>
     */
    protected void setJavaSection(WorldJavaSection s) {
        this.worldJavaSection = s;
    }
}
