// Autocomplete functionality for email addresses

var addrStr = "";
var strToMatch = "";

// array of addr divs
var aDivArray = new Array();

// index of currently selected addr div
var currADivIdx = 0;

function AutoComplete(textBox, popupDiv) {

    this.textBox = textBox;
    this.popupDiv = popupDiv;

    // Attach event handlers to the text box
    textBox.AutoComplete = this;
    textBox.onkeyup = keyPressed;
    textBox.onblur = AutoComplete.prototype.onTextBlur;
}

AutoComplete.prototype.onchange = function() {

    this.hidePopup();

    addrStr = this.textBox.value;

    var lastComma = addrStr.lastIndexOf(',');

    if (lastComma != -1) {
        strToMatch = addrStr.slice(lastComma + 1);
        addrStr = addrStr.slice(0, lastComma) + ", ";
        while (strToMatch.charAt(0) == ' ') {
            strToMatch = strToMatch.slice(1);
        }
    } else {
        strToMatch = addrStr;
        addrStr = "";
    }

    // Get the matching string out of the Address Cache
    // TO DO:  Get this as an array of strings directly
    var addrs = bridge.findAddresses(strToMatch).toString();

    // Check for no matching addresses
    if (addrs == "[]") {
        return;
    }

    // Clear off the starting and ending brackets
    addrs = addrs.substring(1, addrs.length() - 1);

    var addrsArray = new Array();
    addrsArray = addrs.split(",", addrs.length());

    // Clear out the popup div
    while (this.popupDiv.hasChildNodes()) {
        this.popupDiv.removeChild(this.popupDiv.firstChild);
    }
    aDivArray = new Array(addrsArray.length);

    // Populate the popup div with matching addresses
    for (var i = 0; i < addrsArray.length; i++) {

        var popupDiv = document.createElement('div');
        this.popupDiv.appendChild(popupDiv);
        popupDiv.innerHTML = addrsArray[i];
        popupDiv.onmousedown = AutoComplete.prototype.onDivMouseDown;
        popupDiv.onmouseover = AutoComplete.prototype.onDivMouseOver;
        popupDiv.onmouseout = AutoComplete.prototype.onDivMouseOut;
        popupDiv.AutoComplete = this;   
        aDivArray[i] = popupDiv;
    }
    currADivIdx = 0;

    this.showPopup();

    selectADiv(aDivArray[currADivIdx]);
}

AutoComplete.prototype.onDivMouseDown = function() {

    // Convert character equivalents for use in the text box
    // Insert back to text box and append a comma to prepare for
    // next address
    this.AutoComplete.textBox.value = addrStr + convertHTML(this.innerHTML) + ", ";
    setTimeout("focusTextBox()", 0);
}

AutoComplete.prototype.onDivMouseOver = function() {
    selectADiv(this);
}

AutoComplete.prototype.onDivMouseOut = function() {
    deselectADiv(this);
}

AutoComplete.prototype.onTextBlur = function() {
    this.AutoComplete.onblur();
}

AutoComplete.prototype.onblur = function() {
    this.popupDiv.style.visibility = "hidden";
}

AutoComplete.prototype.hidePopup = function() {
    this.popupDiv.style.visibility = "hidden";
}

AutoComplete.prototype.showPopup = function() {
    this.popupDiv.style.visibility = "visible";
}

/**
 * Handle keyboard input to select addresses
 */
function keyPressed(evt) {

    switch (evt.keyCode) {

        // Arrow down key
        case 40:
            selNextADiv();
            evt.cancelBubble = true;
            return;

        // Arrow up key
        case 38: 
            selPrevADiv();
            evt.cancelBubble = true;
            return;

        // Enter key
        case 13: 
            // Capture the selected address
            this.AutoComplete.textBox.value = addrStr + convertHTML(aDivArray[currADivIdx].innerHTML) + ", ";
            this.AutoComplete.hidePopup();
            setTimeout("focusTextBox()", 0);
            evt.cancelBubble = true;
            return;
    }
    this.AutoComplete.onchange();
}

/*
 * Convert character equivalents for use in the text box
 */
function convertHTML(str) {

    var conv = str.replace(new RegExp("&lt;", "g"), "<");
    conv = conv.replace(new RegExp("&gt;", "g"), ">");
    return conv.replace(new RegExp("&quot;", "g"), "\"");
}

/*
 * Select the next addr div entry
 */
function selNextADiv() {

    if (currADivIdx < (aDivArray.length - 1)) {
        deselectADiv(aDivArray[currADivIdx]);
        currADivIdx++;
        selectADiv(aDivArray[currADivIdx]);
    }
}

/*
 * Select the previous addr div entry
 */
function selPrevADiv() {

    if (currADivIdx > 0) {
        deselectADiv(aDivArray[currADivIdx]);
        currADivIdx--;
        selectADiv(aDivArray[currADivIdx]);
    }
}

/*
 * Select the specified addr div
 */
function selectADiv(aDiv) {

    aDiv.className = "AutoCompleteHighlight";
}

/*
 * Deselect the specified addr div
 */
function deselectADiv(aDiv) {

    aDiv.className = "AutoCompleteBackground";
}

/*
 *  Bring focus to and select the text box
 */
function focusTextBox() {
    this.AutoComplete.textBox.blur();
    this.AutoComplete.textBox.focus();
    this.AutoComplete.textBox.select();
}
