
// Common section page javascript, (c) 2002-2005 Pepper Computer, Inc.
// $Id: commonsection.js,v 1.23.2.4 2006/10/06 19:10:21 bill.filler Exp $

var tree, treeChildren, pageframe, sectionID; 
var trackSelection = false;
var deleteInProgress = false;
var ignoreSelectionEvents = false;

// Function to perform page init after the Java bridge is up
function initPage(treeid) {

    tree = document.getElementById(treeid);

    // Set the focus to the tree and select the first entry
    tree.focus();
    if (tree.view.rowCount != 0) {
        tree.view.selection.select(0);
    }
}

// Function to perform page init after the Java bridge is up
function initPage(treeid, treechildrenid) {
    tree = document.getElementById(treeid);

    // Set the focus to the tree and select the first entry
    tree.focus();
    if (tree.view.rowCount != 0) {
        tree.view.selection.select(0);
    }

    treeChildren = document.getElementById(treechildrenid);
}

// Initialize a page that contains a tree and an optional pageframe
// @param treeid The id of the tree
// @param treechildrenid The id of the treechildren element of the tree
// @param pageframeid The id of the iframe or null
// @param thesectionid The id of the section
// @param selectionTrack boolean for whether or not to track selection in the tree
function initPage(treeid, treechildrenid, pageframeid, thesectionid, selectionTrack) {

    tree = document.getElementById(treeid);
    if (treechildrenid != null) {
        treeChildren = document.getElementById(treechildrenid);
    }

    if (pageframeid != null) {
        pageframe = document.getElementById(pageframeid);
    }
    sectionID = thesectionid;
    trackSelection = selectionTrack;

    if (trackSelection) {
        var id = bridge.getSelectedId(sectionID);
        var theRow = getRowForId(id);
        selectTheRow(theRow);
    } else {
        selectTheRow(0);
    }
}

// select the specified row in the tree and make sure it's visible
function selectTheRow(rowNum) {
    tree.focus();

    // Select item after the last one deleted
    if (rowNum < tree.view.rowCount) {
        tree.view.selection.select(rowNum);
        tree.treeBoxObject.ensureRowIsVisible(rowNum);
    } else {
        tree.view.selection.select(tree.view.rowCount - 1);
        tree.treeBoxObject.ensureRowIsVisible(tree.view.rowCount - 1);
    }
}

// call into the framework to set the selected page id
function setSelected() {

    if (tree.currentIndex >= 0) {
        var pageIds = findSelectedPages();
        if (pageIds.length > 0) {
            bridge.setSelectedId(sectionID, pageIds[0]);
        } else {
            bridge.setSelectedId(sectionID, '');
        }

    } else {
       bridge.setSelectedId(sectionID, '');
    }
}


// Function to show the currently selected page
function showPage() {
    if (trackSelection) {
        setSelected();
    }
    var id = tree.contentView.getItemAtIndex(tree.currentIndex).getAttribute('id');
    var url = "pepper://" + packageId + "/" + id + "?isPage=true";

    bridge.action('ShowPage', url);
}



// Function to move the selected page(s)
function movePage() {
    var pageIDs = findSelectedPages();
    if (pageIDs.length == 0) {
        return;
    }

    var theId;
    if (trackSelection) {
        var theRow = getRowForId(pageIDs[0]);
        // store the id of the row before this 
        if (theRow > 0) {
            theId = getIdForRow(theRow - 1);
        } else {
            theId = '';
        }

        // the previous item will get selected when the page is refreshed
        bridge.setSelectedId(sectionID, theId);
    }

    bridge.action('MovePage', pageIDs);
}

// Empty the deleted section
function emptyDeleted() {
    // do same logic as DeletePage, just do it on all
    // of the rows, not just the selected rows
    handleDelete('DeletePage', true);
}

        
// Function to delete the selected page(s)
function deletePage() {
    handleDelete('DeletePage', false);
}

// delete all of the pages or just the selected pages from the tree
// if deleteAll is false
function handleDelete(actionName, deleteAll) {
    try {
        // need to prevent deletes while a delete is in progress
        if (deleteInProgress) {
            return;
        } else {
            deleteInProgress = true;
        }
        var pageIDs;

        if (!deleteAll) {
            pageIDs = findSelectedPages();
        } else {
            pageIDs = findAllPages();
        }

        if (pageIDs.length == 0) {
            deleteInProgress = false;
            return;
        }

        // if only one page being deleted
        // remove it directly from tree to speed
        // things up. Otherwise, framework will
        // callback into removeTreeItems when the page
        // is actually deleted
        if (pageIDs.length == 1) {
            removeTreeItems(pageIDs);
        }

        // framework will callback finishDelete() or
        // deleteFinished() when the action
        // is complete. 
        bridge.action(actionName, pageIDs);
        
    } catch (e) {
        deleteInProgress = false;
    }
}

// callback fromm DeletePageAction when deletion of single page
// is complete
function deleteFinished() {
    deleteInProgress = false;
}

// callback from DeletePageAction when multiple page deletion 
// is complete
function finishDelete(pageIDs) {
    removeTreeItems(pageIDs);
    deleteInProgress = false;
}

// Function to export the selected page(s)
function doExport() {
    var pageIDs = findSelectedPages();
    if (pageIDs.length == 0) {
        return;
    }
    bridge.action('Export', pageIDs);
}

//Remove the treeItems with id matching passed in pageIDs list
function removeTreeItems(pageIDs) {

    //set flag because any trees that have onSelect listeners
    //will get selection events fired when tree items are removed.
    //This happens in Mail and Journal. We want to not do the
    //normal selection processing in this case
    ignoreSelectionEvents = true;

    // Remove pages from the DOM since it's faster than waiting
    // around for a refresh.
    var lastIndex = 0;

    for (var i = 0; i < pageIDs.length; i++) {
        try {
            var treeitem = document.getElementById(pageIDs[i]);
            if (i == pageIDs.length - 1) {
                lastIndex = tree.contentView.getIndexOfItem(treeitem);
            }
            treeitem.parentNode.removeChild(treeitem);
        } catch (e) {
        }
    }

    ignoreSelectionEvents = false;

    try {
        // Select item after the last one deleted
        if (lastIndex < tree.view.rowCount) {
            tree.view.selection.select(lastIndex);
        } else {
            tree.view.selection.select(tree.view.rowCount - 1);
        }
    } catch (ef) {
    }
}




function updateSelection(id) {
    var entry = document.getElementById(id);
    if (entry == null) return;
    var index = tree.contentView.getIndexOfItem(entry);
    tree.view.selection.select(index);
}

// get the row number of the treeitem specified by the id
function getRowForId(id) {
    var entry = document.getElementById(id);
    if (entry == null) 
        return 0;
    var index = tree.contentView.getIndexOfItem(entry);
    return index;
}

// get the id attribute for the element at the specified row num
function getIdForRow(rowNum) {
    var view = tree.contentView;
    if (view.rowCount == 0) {
        return '';
    }
    return view.getItemAtIndex(rowNum).getAttribute('id');
}

// Function to find selected pages
function findSelectedPages() {
    var start = new Object();
    var end = new Object();
    var numRanges = tree.view.selection.getRangeCount();
    var pageIDs = new Array();
    var view = tree.contentView;
    if (view.rowCount == 0) {
        // getItemAtIndex will blow up if no rows, so short-circuit
        return pageIDs;
    }

    for (var t = 0; t < numRanges; t++) {
        tree.view.selection.getRangeAt(t, start, end);
        for (var v = start.value; v <= end.value; v++) {
            var id = view.getItemAtIndex(v).getAttribute('id');
            if (id != '') {
                pageIDs.push(id);
            }
        }
    }

    return pageIDs;
}

// return an array of all pagesIds displayed in the tree
function findAllPages() {

    var pageIDs = new Array();
    var view = tree.contentView;
    var rowCount = view.rowCount;
    if (rowCount == 0) {
        // getItemAtIndex will blow up if no rows, so short-circuit
        return pageIDs;
    }

    for (var i = 0; i < rowCount; i++) {
       var id = view.getItemAtIndex(i).getAttribute('id');
       if (id != '') {
           pageIDs.push(id);
       }
    }

    return pageIDs;
}

function sortColumn(column) {
    bridge.action('SortPage', column);
}

//if ctrl-a pressed, select everything in the tree
function handleKeypress(evt, theTree) {

    if (evt.ctrlKey) {
        var theChar = String.fromCharCode(evt.charCode).toLowerCase();
        if (theChar == 'a') {
            evt.stopPropagation();
            evt.preventDefault();
            selectAll();

        } else if (theChar == 'g') {
            evt.stopPropagation();
            evt.preventDefault();
            unselectAll();

        }else if (theChar == 'c') {
            evt.stopPropagation();
            evt.preventDefault();
            copySelectionImpl();
        }
    }
}

// Show page on double-click.  Used for XUL tables.
function handleDoubleClick(event) {
    if (trackSelection) {
        setSelected();
    }

    showPage();
    event.preventDefault();
}

//this will select all nodes in the tree
function selectAll() {

    if (tree == null) {
        return false;
    }
    
    tree.focus();
    tree.view.selection.selectAll();

    return true;

}

//unselect all selected rows
function unselectAll() {

    if (tree == null) {
        return false;
    }

    tree.focus();
    tree.view.selection.clearSelection();
    return true;
}

//Copy selection from tree to the Mozilla clipboard
function copySelection() {
    //must kick off a timer to do the work
    //or else we get a failure trying to enable
    //UniversalXPConnect privilege if this method
    //is called from Java
    setTimeout('copySelectionImpl()', 5);
}

function copySelectionImpl() {

    //must be enabled to copy using the clipboard
    netscape.security.PrivilegeManager.enablePrivilege("UniversalXPConnect");

    try {
        var theTree = tree;

        if (theTree == null) {
            return false;
        }

        //BF - TODO: need to figure out which column's text we should copy
        //This is just temporary
        var copytext = theTree.contentView.getItemAtIndex(theTree.currentIndex).getAttribute('id');
        //var copytext = theTree.view.getCellText(1, "title");
        //var copytext = 'hey now=' + theTree.currentIndex;
        //alert('copyText='+copytext);
        
        var str = Components.classes["@mozilla.org/supports-string;1"].
            createInstance(Components.interfaces.nsISupportsString);


        if (!str) return false;
        str.data = copytext;

        var trans = Components.classes["@mozilla.org/widget/transferable;1"].
            createInstance(Components.interfaces.nsITransferable);
        if (!trans) return false;

        trans.addDataFlavor("text/unicode");
        trans.setTransferData("text/unicode",str,copytext.length * 2);

        var clipid = Components.interfaces.nsIClipboard;
        var clip = Components.classes["@mozilla.org/widget/clipboard;1"].getService(clipid);
        if (!clip) return false;

        clip.setData(trans,null,clipid.kGlobalClipboard);

    } catch (e) {
        //alert(e);
        return false;
    }

    return true;

}

//Remove all the child nodes from the
//<treechildren> node
function removeTreeChildren(treeChildrenNode) {

    if (treeChildrenNode == null) {
        return;
    }

    ignoreSelectionEvents = true;
    
    try {
        //get treeChildren element's children
        var items = treeChildrenNode.childNodes;
        var numChildren = items.length;

        for (var i = numChildren -1; i >= 0; i--) {
            treeChildrenNode.removeChild(items[i]);
        }
    } catch (e) {
    }

    ignoreSelectionEvents = false;
}

// Function to show the currently selected page in the iframe
// returns the treeItem of the selection (if the selection has changed)
// or null otherwise or if a delete is in progress
function previewPage() {

    // if we are deleting, don't do anything. For some reason
    // selection events are fired (which cause the onSelect="previewPage()"
    // method to be called) when we add or remove items directly
    // in the DOM, even though we are not selecting anything. 
    // This causes major problems/deadlocks when deleting from the
    // tree. When adding pages, we handle differently because we
    // still want to enable selection while new messages are coming in.
    // We check the current url to see if it's changed before proceeding.
    if (ignoreSelectionEvents) {
        return null;
    }
    // Make sure there are pages in the tree and something is selected
    var selectedIndex = tree.currentIndex;

    if (tree.view.rowCount > 0 && selectedIndex >= 0) {
	
        var selItem = null;
        try {
            selItem = tree.contentView.getItemAtIndex(selectedIndex);
            var id = selItem.getAttribute('id');
            if (id == '') {
                return null;
            }
         } catch (e) {
            return null;
         }
    	
        // Show the page in the frame
        var pageURL = "pepper://" + packageId + "/" + id + "?isPage=true&inFrame=true";

        // if we are already showing this page, just bail
        if (pageframe.getAttribute("src") == pageURL) {
            return null;
        }

        pageframe.setAttribute("src", pageURL);

        // return the selected treeItem
        return selItem;
		
    } else {

        // No pages (probably all deleted), so show a blank page in the frame
        pageframe.setAttribute("src", "about:blank");
        return null;
    }
}

// add a top level click handler to the document
function addClickHandler() {
    document.addEventListener("click", theClickHandler, false);
}

// set up the click handler on the embedded iframe
// typically called from the "onload" of the iframe element
function onFrameLoad() {
    netscape.security.PrivilegeManager.enablePrivilege("UniversalXPConnect");
    if (pageframe != null) {
        pageframe.contentDocument.addEventListener("click", theClickHandler, false);
    }
}

// click handler for iframe in a frameset, ie. mail, journal, help, etc.
// will capture the click event and show the page in the package's
// web tab (if applicable) or the web browser
function theClickHandler(aEvent) {

    // if right mouse, just return
    if (aEvent.which != 1) {
        return;
    }

    var theNode = aEvent.target;
    var theClickedURL = null;
    //get the href from the node if it has one
    var href = theNode.href;

    // try parent as the target could be an <img> tag
    // that is parented by an <a href=""> tag
    if (href == null) {
        var parent = theNode.parentNode;
        if (parent != null) {
            href = parent.href;
        }
    }

    if (href != null && href.indexOf("pepper://") != 0) {

        // check if this is special content that the keeper handles
        // (like mp3's). If so, just return and the right thing 
        // will happen
        var keeperHandles = bridge.isContentHandlerRegistered(href);
        if (keeperHandles.equals("true")) {
            return;
        } else {
            aEvent.preventDefault();
            aEvent.stopPropagation();
            bridge.action("ShowPage", href);
        }
    } 
}

