<?xml version="1.0" encoding="UTF-8"?>

<!-- sort-filter.xsl - This stylesheet is used by the class SortPageAction to
     sort a package's top-level pages. -->

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>

  <!-- Set up default parameters for sorting.  -->

  <xsl:param name="sortBy" select="'title'" />
  <xsl:param name="sortCase" select="'lower-first'" />
  <xsl:param name="sortOrder" select="'ascending'" />
  <xsl:param name="sortKey" select="'*'" />
  <xsl:param name="sortType" select="'text'" />

  <!-- This template controls the sorting of the 'packageList' root element.  It
       first copies the cover, then all of the sections, then it sorts page
       elements based upon the sort params; finally it copies any pageRemoved
       elements. -->

  <xsl:template match="/packageList">
    <xsl:copy>
      <xsl:apply-templates select="@*" />
      <xsl:apply-templates select="page[@type = 'cover']" />
      <xsl:apply-templates select="section" />
      <xsl:apply-templates select="page[@type != 'cover']">
         
        <!-- see the big red book for explanation of sort select expression. -->
        <xsl:sort select="@*[local-name()=$sortBy]|*[local-name()=$sortBy]" order="{$sortOrder}" case-order="{$sortCase}" data-type="{$sortType}"/>
      </xsl:apply-templates>
    </xsl:copy>
  </xsl:template>

  <!-- This template controls the sorting of the '/section' root element.  It
       simply copies the attributes of section, then it sorts page elements
       based upon the sort params; finally it copies any pageRemoved elements. -->

  <xsl:template match="/section">
    <xsl:copy>
      <xsl:apply-templates select="@*" />
      <!-- copy the rest of the elements unsorted  -->
      <xsl:copy-of select="*[local-name()!='page']"/>

      <xsl:apply-templates select="page">
         
        <!-- see the big red book for explanation of sort select expression. -->
        <xsl:sort select="@*[local-name()=$sortBy]|*[local-name()=$sortBy]" order="{$sortOrder}" case-order="{$sortCase}" data-type="{$sortType}"/>
      </xsl:apply-templates>
    </xsl:copy>
  </xsl:template>

<!-- Sort elements in a page by attribute or element value on the sortKey element-->

  <xsl:template match="/page">
    <xsl:copy>
      <xsl:apply-templates select="@*" />
      <!-- Copy the other elements -->
      <xsl:copy-of select="*[local-name()!=$sortKey]"/>
      <!-- Sort the selected element -->   
      <xsl:apply-templates select="*[local-name()=$sortKey]">
        <xsl:sort select="@*[local-name()=$sortBy]|*[local-name()=$sortBy]" order="{$sortOrder}" case-order="{$sortCase}" data-type="{$sortType}"/> 
      </xsl:apply-templates>
    </xsl:copy>
  </xsl:template>



  <!-- Default template, recursively copies attributes and nodes. -->

  <xsl:template match="@*|node()">
    <xsl:copy>
      <xsl:apply-templates select="@*|node()" />
    </xsl:copy>
  </xsl:template>

</xsl:stylesheet>
