// $Id: MailSettings.js,v 1.5 2006/07/21 18:37:03 steve.magoun Exp $
// Javascript for the mail settings on the User Settings page.

/*** Constants ***/
var POP3_PORT = 110;
var IMAP_PORT = 143;
var SMTP_PORT = 25;

var AUTH_NONE     = "none";
var AUTH_PASSWORD = "password";

var SAME_RELATION       = "same";
var STARTSWITH_RELATION = "startsWith";
var NO_RELATION         = "none";

// XMLHttpRequest
var req;
// MailProviders document loaded by XMLHttpRequest
var mailProviders;

// ID of the currently-selected ISP
var curISPID;

// TODO: i18n
// Text for the username field
var userNameText = "User Name:";
// Text for the username field for AOL, AIM
var aolScreenNameText = "Screen Name:";

/* 
 * Set settings for the selected ISP. If necessary, displays the location
 * dropdown for the ISP.
 *
 * formElement - ISP <select> form element
 * ISP - id of the ISP. Must match an ISP id in MailProviders.xml
 * clear - True to clear existing settings, false to leave them as-is. 
 *         Use true when changing settings, false when showing the page 
 *         for the first time.
 */
function changeISP(formElement, ISP, clear) {

	// Form we're working on. Only supports form numbers up to 9
	var formNum = formElement.id.charAt(formElement.id.length - 1);

	// Cache new ISP
	curISPID = ISP;

	// List of form element IDs set by the user for this ISP
	var userSetIDs = getSettableElementList(ISP, formNum, true);
	// List of table rows containing elements set by the user
	var userSetRows = getRowsFromIDs(userSetIDs);
	// List of form elements set by the user for this ISP
	var userSetElements = getElementsFromIDs(userSetIDs);
	
	// List of form element IDs set automatically for this ISP
	var autoSetIDs = getSettableElementList(ISP, formNum, false);
	// List of table rows containing elements set automatically
	var autoSetRows = getRowsFromIDs(autoSetIDs);
	// List of form elements set automatically for this ISP
	var autoSetElements = getElementsFromIDs(autoSetIDs);

	// Leave in for debugging
	//alert("userSetIDs: " + userSetIDs);
	//alert("autoSetIDs: " + autoSetIDs);

	// Hide autoset fields
	setDisplayStyle(autoSetRows, "none");
	
	// Disable autoset elements
	setEnabled(autoSetElements, false);
	
	// If the isp is the special "choose an ISP" value, hide 
	// user-settable settings, clear all values and bail - the mail 
	// account isn't configured.
	if (ISP == "ChooseISP") {
		setDisplayStyle(userSetRows, "none");
		clearSettings(autoSetElements);
		clearSettings(userSetElements);

		var locationTR = document.getElementById("location" + formNum + "tr");
		locationTR.style.display = "none";
		return;
	}
	
	// Clear out existing settings
	if (clear) {
		clearSettings(autoSetElements);
		clearSettings(userSetElements);
	
		// Reset selected protocol list
		var protocolSelect = document.getElementById("protocol" + formNum);
		protocolSelect.selectedIndex = 0;
	
		// If it's the "Other" ISP, make sure the mailserver ports are filled
		// in correctly
		if (ISP == "Other") {
			setProtocol(protocolSelect);
		}
	}

	// Load locations
	var locIter = mailProviders.evaluate("//mailProviders/isp[@id='" + ISP + "']/location",
		mailProviders, null, XPathResult.ORDERED_NODE_ITERATOR_TYPE, null);
	
	/// Cache selected location (from page data) then clear location list
	var locationSelect = document.getElementById("location" + formNum);
    var oldSelectedIndex = locationSelect.selectedIndex;
    var oldSelectedLocID;
    if (oldSelectedIndex > -1) {
      oldSelectedLocID = locationSelect.options[oldSelectedIndex].value;
    }
	locationSelect.options.length = 0;

    // Populate list with locations, selecting the one that was 
    // previously selected (or the first one, if clearing)
	var locCount = 0;
	var selectedLoc;
	while (loc = locIter.iterateNext()) {
		var locID = loc.getAttribute("id");
		var locName = loc.getAttribute("name");
		locationSelect.options[locCount] = new Option(locName, locID);
		if (clear) {
            if (locCount == 0) {
                selectedLoc = locID;				
            }
        } else {
            if (locID == oldSelectedLocID) {
              selectedLoc = locID;
              locationSelect.selectedIndex = locCount;
            }
        }
		locCount++;
	}

	// Show location list only if there's more than one location for the ISP
	var locTRStyle = (locCount > 1) ? "" : "none";
	var locationTR = document.getElementById("location" + formNum + "tr");
	locationTR.style.display = locTRStyle;

	// Set field values
	selectLocation(locationSelect, selectedLoc);
	
	// Rename the AOL username field to "Screen name"
	var usernameLabelTD = document.getElementById("usernameLabel" + formNum);
	usernameLabelTD.innerHTML = (ISP == "AOL" || ISP == "AIM") ? aolScreenNameText : userNameText;
	
	// Attach a listener to the username/email field if necessary
	// Use onkeyup instead of onkeypress since onkeypress fires before
	// the value of the input field changes; we need an event that fires
	// after the value of the input changes. By using onkeyup we lose the
	// ability to handle repeating keystrokes in realtime, but so what?
	if (contains(autoSetIDs, "username" + formNum)) {
		var mailAddressElement = document.getElementById("mailAddress" + formNum);
		mailAddressElement.onkeyup = mailAddressChanged;
	} else if (contains(autoSetIDs, "mailAddress" + formNum)) {
		var usernameElement = document.getElementById("username" + formNum);
		usernameElement.onkeyup = usernameChanged;
	}
	
	// Enable user-set elements
	setEnabled(userSetElements, true);

	// Show user-set fields
	setDisplayStyle(userSetRows, "");
}


/* 
 * Set server values based on the ISP location.
 *
 * formElement - Location <select> form element
 * location - ID of the location. Must match a location ID for the
 *     currently-selected ISP (curISPID) in MailProviders.xml.
 */
function selectLocation(formElement, location) {

	// Form we're working on. Only supports form numbers up to 9
	var formNum = formElement.id.charAt(formElement.id.length - 1);

	// List of form element IDs set automatically for this ISP
	var autoSetIDs = getSettableElementList(curISPID, formNum, false);

	// Load POP3/IMAP server
	var incomingIter = mailProviders.evaluate("//mailProviders/isp[@id='" + curISPID 
		+ "']/location[@id='" + location + "']/server[@protocol='pop3' or @protocol='imap']",
		mailProviders, null, XPathResult.ORDERED_NODE_ITERATOR_TYPE, null);

	// Grab the first incoming mailserver in the list
	// If there's no server listed, show all fields so the user
	// can enter something by hand. Used for the "Other" ISP.
	var server = incomingIter.iterateNext();
	if (!server) {
		return;	
	}

	// Set username or email if necessary
	if (contains(autoSetIDs, "username" + formNum)) {
		setUsernameFromMailAddress(formNum);
	} else if (contains(autoSetIDs, "mailAddress" + formNum)) {
		setMailAddressFromUsername(formNum);
	}

	/* Protocol, incoming/outgoing host/port are always set automatically */

	var protocol = server.getAttribute("protocol");
	var host = getChildText(server, "host");
	var port = getChildText(server, "port");
	if (port == null || port == "") {
		if (protocol == "pop3") {
			port = POP3_PORT;	
		} else if (protocol == "imap") {
			port = IMAP_PORT;	
		}
	}

	// Set protocol type
	var protocolSelect = document.getElementById("protocol" + formNum);
	for (i = 0; i < protocolSelect.options.length; i++) {
		var option = protocolSelect.options[i];
		if (option.value == protocol) {
			protocolSelect.selectedIndex = i;
			break;
		}
	}
	
	// Set host
	var hostField = document.getElementById("incomingHost" + formNum);
	hostField.value = host;
	
	// Set port if present
	var portField = document.getElementById("incomingPort" + formNum);
	portField.value = port;
	
	// Load SMTP server
	var outgoingIter = mailProviders.evaluate("//mailProviders/isp[@id='" + curISPID 
		+ "']/location[@id='" + location + "']/server[@protocol='smtp']",
		mailProviders, null, XPathResult.ORDERED_NODE_ITERATOR_TYPE, null);

	// Grab the first outgoing mailserver in the list
	server = outgoingIter.iterateNext();

	// Set host
	host = getChildText(server, "host");
	var hostField = document.getElementById("outgoingHost" + formNum);
	hostField.value = host;
	
	// Set port if present
	port = getChildText(server, "port");
	if (port == null || port == "") {
		port = SMTP_PORT;
	}
	var portField = document.getElementById("outgoingPort" + formNum);
	portField.value = port;
	
	// Set auth if present
	auth = getChildText(server, "auth");
	if (auth == null || auth == "") {
		auth = AUTH_NONE;
	}
	var authField = document.getElementById("outgoingAuth" + formNum);
	authField.value = auth
}


/* 
 * Set default port numbers when the user changes account types.
 * Currently used only for the "other" ISP.
 *
 * formElement - Protocol <select> form element
 */
function setProtocol(formElement) {

	// Form we're working on. Only supports form numbers up to 9
	var formNum = formElement.id.charAt(formElement.id.length - 1);

	// Set protocol type
	var protocolSelect = document.getElementById("protocol" + formNum);
	var protocol = protocolSelect.options[protocolSelect.selectedIndex].value;
	
	// Set incoming port. Overrides whatever the user set
	var portField = document.getElementById("incomingPort" + formNum);
	var port = (protocol == "pop3") ? POP3_PORT : IMAP_PORT;
	portField.value = port;
	
	// Set outgoing port
	port = SMTP_PORT;
	portField = document.getElementById("outgoingPort" + formNum);
	portField.value = port;
}


/*
 * Get a list of form element IDs. If userSettings is true,
 * creates a list of form elements set by the user. If userSettings 
 * is false, creates a list of form elements set automatically.
 *
 * ISP - id of the ISP the settings are for. Must match an ISP id 
 * 		in MailProviders.xml
 * formNum - Index of the email settings we're working on
 * userSettings - true to get a list of elements set by the user,
 * 		false to get a list of elements set automatically 
 *
 * Returns an Array of form element IDs
 */
function getSettableElementList(ISP, formNum, userSettings) {
	var ret = new Array(0);

	// Load ISP element from DOM
	var result = mailProviders.evaluate("//mailProviders/isp[@id='" + ISP + "']",
		mailProviders, null, XPathResult.FIRST_ORDERED_NODE_TYPE, null);
	var ispNode = result.singleNodeValue;
	
	var askEmail = true;
	var askUsername = true;
	var ispExists = (ispNode) ? true : false;
	
	if (ispExists) {
		var relation = ispNode.getAttribute("emailUsernameRelation"); 
		if (relation == STARTSWITH_RELATION || relation == SAME_RELATION) {
			// Ask for email address, derive username
			if (ISP == "AOL" || ISP == "AIM") {
				// AOL/AIM are a special case. Ask for screen name, derive email
				askEmail = false;
				askUsername = true;
			} else {
				askEmail = true;
				askUsername = false;
			}
		}
	} else {
		// If no ISP, always ask the user to set email + password
		askEmail = true;
		askUsername = true;
	}
	
	if (askUsername == userSettings) {
		// Username
		ret.push("username" + formNum);
	}

	if (askEmail == userSettings) {
		// Email address
		ret.push("mailAddress" + formNum);
	}
	
	// Password, display name are always set by the user
	if (userSettings) {
		// Always ask for password
		ret.push("password" + formNum);

		// TODO: Do we need a display name for AOL email?
		// Display name
		ret.push("fullName" + formNum);
	}

	// Server settings are always set automatically unless there's no ISP
	if (userSettings != ispExists) {
		// Incoming mail protocol
		ret.push("protocol" + formNum);
		
		// Incoming mail host
		ret.push("incomingHost" + formNum);
	
		// Incoming mail port
		ret.push("incomingPort" + formNum);

		// Outgoing mail host
		ret.push("outgoingHost" + formNum);
		
		// Outgoing mail port
		ret.push("outgoingPort" + formNum);
		
		// Outgoing mail auth
		ret.push("outgoingAuth" + formNum);
	}

	return ret;
}


/*
 * Return a list of table row elements corresponding to a list of
 * element IDs. Assumes each row has id=formElementID+"tr"
 */
function getRowsFromIDs(idList) {
	var ret = new Array(idList.length);
	for (i = 0; i < idList.length; i++) {
		ret[i] = document.getElementById(idList[i] + "tr");
	}
	return ret;
} 


/*
 * Return a list of form elements corresponding to a list of
 * element IDs.
 */
function getElementsFromIDs(idList) {
	var ret = new Array(idList.length);
	for (i = 0; i < idList.length; i++) {
		ret[i] = document.getElementById(idList[i]);
	}
	return ret;
} 


/*
 * Set the display style of each element in a list of elements. 
 *
 * elements - array of elements
 * style - display style, usually "" or "none"
 */
function setDisplayStyle(elements, style) {
	for (i = 0; i < elements.length; i++) {
		elements[i].style.display = style;
	}
}


/*
 * Set/remove the disabled flag of each form element in a list
 * of form elements.
 *
 * elements - array of form elements
 * disabled - true if the elements should be enabled, false if
 *            they should be disabled.
 */
function setEnabled(elements, enabled) {
    for (i = 0; i < elements.length; i++) {
        elements[i].disabled = !enabled;
    }
}


/*
 * Reset the form elements in the list.
 *
 * formElements - List of form elements
 */
function clearSettings(formElements) {
	for (i = 0; i < formElements.length; i++) {
		var element = formElements[i];
		if (element.value) {
			element.value = "";
		}
	}
}


/*
 * Determine whether an array contains an element.
 */
function contains(array, key) {
	for (i = 0; i < array.length; i++) {
		if (array[i] == key) {
			return true;
		}
	}
	return false;
}


/*
 * Get the text of the first child node with the given name
 */
function getChildText(node, childName) {
	var children = node.getElementsByTagName(childName);
	if (children == null || children.length == 0) {
		return null;
	}
	return children.item(0).firstChild.nodeValue;
}


/*
 * Load the MailProviders.xml doc into the global var req. 
 * Registers processReqChange() as a handler for the request. 
 */
function loadMailProviders(url) {
	try {
		//alert("opening request: " + url);
		//netscape.security.PrivilegeManager.enablePrivilege("UniversalBrowserRead");
		//alert("asked for permission");
		req = new XMLHttpRequest();
		req.onreadystatechange = processReqChange;
		req.open("GET", url, true);
		//alert("opened request");
		req.send(null);
	} catch(e){
		alert("Error: " + e);
	};
}


/*
 * Event handler for XMLHttpRequest populates mailProviders and
 * sets initial server settings once MailProviders.xml has been 
 * loaded.
 */
function processReqChange() {
	// only if req shows "loaded"
	if (req.readyState == 4) {
		// only if "OK" or "0" (file: requests return status of 0)
		if (req.status == 200 || req.status == 0) {
			//alert("Loaded mail provider!");
			mailProviders = req.responseXML;
			// Show selected mail settings only after mailProviders is loaded
			showSettings();
		 } else {
			alert("There was a problem retrieving the XML data:\n" +
				req.statusText + " " + req.status);
		 }
	}
}


/* 
 * Show the correct settings on startup
 */
function showSettings() {
	var ispSelect = document.getElementById('isp1');
	var selectedISP = ispSelect.options[ispSelect.selectedIndex].value;
	changeISP(ispSelect, selectedISP, false);
}


/*
 * Show the hidden settings for this ISP
 *
 * button - button that triggered the event
 * ISP - ISP toggle settings for
 * formNum - Number of the form to toggle settings for
 */
function toggleHiddenSettings(button, ISP, formNum) {
	// List of form element IDs set automatically for this ISP
	var autoSetIDs = getSettableElementList(ISP, formNum, false);
	// List of table rows containing elements set automatically
	var autoSetRows = getRowsFromIDs(autoSetIDs);

	if (autoSetRows == null || autoSetRows.length == 0) {
		// Nothing to do
		return;
	}

	// Find out whether the rows are hidden or visible
	var newVal = (autoSetRows[0].style.display == "none") ? "" : "none"; 

	// Show/hide autoset fields
	setDisplayStyle(autoSetRows, newVal);
}


/*
 * Callback invoked during an onkeypress to change the value of the
 * autoset email field.
 *
 * event - A KeyboardEvent
 */
function usernameChanged(event) {
	var targetID = event.target.id;
	var formNum = targetID.charAt(targetID.length - 1);
	setMailAddressFromUsername(formNum);
}


/*
 * Callback invoked during an onkeypress to change the value of the
 * autoset username field.
 *
 * event - A KeyboardEvent
 */
function mailAddressChanged(event) {
	var targetID = event.target.id;
	var formNum = targetID.charAt(targetID.length - 1);
	setUsernameFromMailAddress(formNum);
}


/*
 * Set the mailAddress field of the given form based on the value
 * of the username field.
 *
 * formNum - Index of the email settings we're working on
 */
function setMailAddressFromUsername(formNum) {
	var usernameField = document.getElementById("username" + formNum);
	var curUser = usernameField.value;
	
	var result = mailProviders.evaluate("//mailProviders/isp[@id='" + curISPID 
		+ "']/@emailDomain", mailProviders, null, 
		XPathResult.FIRST_ORDERED_NODE_TYPE, null);
	// Anyone know the XPath to get the value of an attribute? I don't...
	var emailDomain = result.singleNodeValue.firstChild.nodeValue;
	
	// TODO: Need to trim values
	
	// TODO: AOL/AIM screen names can have spaces and other nonsense;
	// they need to be cleaned up before they're useful email addrs.
	var newEmail = curUser + "@" + emailDomain;
	var emailField = document.getElementById("mailAddress" + formNum);
	emailField.value = newEmail;
}


/*
 * Set the username field of the given form based on the value
 * of the mailAddress field.
 *
 * formNum - Index of the email settings we're working on
 */
function setUsernameFromMailAddress(formNum) {
	// TODO: Need to trim values

	var mailAddressField = document.getElementById("mailAddress" + formNum);
	var usernameField = document.getElementById("username" + formNum);
	var currAddr = mailAddressField.value;

	var result = mailProviders.evaluate("//mailProviders/isp[@id='" + curISPID 
		+ "']/@emailUsernameRelation", mailProviders, null, 
		XPathResult.FIRST_ORDERED_NODE_TYPE, null);
	// Anyone know the XPath to get the value of an attribute? I don't...
	var relation = result.singleNodeValue.firstChild.nodeValue;

	if (relation == SAME_RELATION) {
		// Username + mail address are the same
		usernameField.value = currAddr;
	} else if (relation == STARTSWITH_RELATION) {
		// Username is email addr up to the @ sign
		var atIndex = currAddr.indexOf('@');
		if (atIndex > -1) {
			usernameField.value = currAddr.substring(0, atIndex);
		} else {
			// Set username directly from mail address, since mail addr's invalid
			usernameField.value = currAddr;
		}
	}
}
