<?xml version="1.0" encoding="utf-8"?>
<!-- Mail settings page stylesheet, (c) 2005 Pepper Computer, Inc. -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
  xmlns:xalan="http://xml.apache.org/xalan" xmlns:pepper="http://www.pepper.com/elements" 
  extension-element-prefixes="pepper">
  <xalan:component prefix="pepper">
    <xalan:script lang="javaclass" src="com.pepper.script.Elements"/>
  </xalan:component>
  <xsl:output method="html"/>
  <xsl:param name="pageNumber" select="'1'" />
  <xsl:param name="pagesInSection" select="'1'" />
  <xsl:param name="packageId" />
  <xsl:param name="design" />
  <xsl:param name="platform" />
  <xsl:param name="setup" />
  <xsl:param name="arch" select="'PC'" />

  <xsl:template match="/">
    <xsl:variable name="addAccount" select="pepper:textString($packageId,'Settings.Personal.AddAccount')" />
    <html xmlns="http://www.w3.org/1999/xhtml">
      <head>
        <xsl:variable name="pageName" select="pepper:nameString($packageId,page/@name)" />
        <title><xsl:value-of select="$pageName"/></title>
        <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
        <link rel="stylesheet" type="text/css" href="{$platform}/resources/styles/styles.css"></link>
      	<xsl:if test="$setup = 'true'"> 
        	<link rel="stylesheet" type="text/css" href="{$design}/design/setup.css"/>
      	</xsl:if>
        <pepper:initscriptbridge package="{$packageId}"/>
        <script language="JavaScript" type="text/javascript" src="{$platform}/resources/xsl/MailSettings.js" />
        <script language="JavaScript" type="text/javascript"> <![CDATA[
            function dummy() {
                // Don't erase this, it's here to force Mozilla to process the next <script>
            }
		]]> </script>
        <script language="JavaScript" type="text/javascript"><![CDATA[
		
            // Collects form values and passes them into the ChangeMailSettings action
            // Probably doesn't work for radio buttons, maybe others too 
            function changeSettings() {
              var vals = new Array();
              var inputs = document.forms[0].elements;
              var xpath;
              var value;
              var i = 0;
              var j = 0;
              for (; i < inputs.length; i++) {
                xpath = inputs[i].getAttribute('nosavexpath');
                if (xpath != null && xpath != "") {
                  if (inputs[i].type == 'checkbox') {
                    value = inputs[i].checked;
                  } else {
                    value = inputs[i].value;
                  }
                  vals[j++] = xpath;
                  vals[j++] = value;
                }
              }
              // HACK: since there's no UI for entering smtp
              // username/password, copy values from the incoming
              // server. Someday we might add those fields to the UI, 
              // for now they're just redundant. 
              // Assumes a single mail account.
              var auth = document.getElementById("outgoingAuth1");
              if (auth.value == 'password') {
                var user = document.getElementById("username1").value;
                var pass = document.getElementById("password1").value;
                vals[j++] = "page/user/emailAccount[position()=1]/outgoingServer/username";
                vals[j++] = user;
                vals[j++] = "page/user/emailAccount[position()=1]/outgoingServer/password";
                vals[j++] = pass; 
              }
              
              // Use syncAction here to ensure that the action completes
              // before the javascript returns. Important because this
              // is called during shutdown, and things are gone by the
              // time the action runs if using bridge.action().
              bridge.syncAction("ChangeMailSettings", vals);
            }

          ]]>
        </script>
      </head>
        <body class="PageBody" onload="loadMailProviders('pepper://{$packageId}/resources/xsl/MailProviders.xml');">
        <xsl:choose> 
          <xsl:when test="$setup = 'true'"> 
            <pepper:pagebar class="PageBar" id="pb-{$packageId}" package="{$packageId}">
              <pepper:pagebarentry key="Setup.Next" script="bridge.action('NextPage');" />
              <pepper:pagebarentry key="Setup.Prev" script="bridge.action('PrevPage');" />
            </pepper:pagebar>
          </xsl:when>
          <xsl:otherwise>
            <pepper:pagebar class="PageBar" id="pb-{$packageId}" package="{$packageId}">
                <pepper:pagebarentry key="PageBar.ShowAllMailSettings"
            	script="toggleHiddenSettings(this, isp1.options[isp1.selectedIndex].value, '1')"/>
            </pepper:pagebar>
          </xsl:otherwise>
        </xsl:choose>

        <!-- Display the page contents -->
        <div class="PageContent">
        <div class="Content">
        <!-- Display the page title -->
        <div class="Title">
          <pepper:textString package="{$packageId}" key="NameKey.Mail.Description"/>
        </div>
          <form>            
            <!-- Display e-mail settings -->
            <table cellpadding="4" cellspacing="0">
              <xsl:for-each select="page/user/emailAccount[position()=1]">
                <tr id="MailAccount1">
                  <td>
                    <table cellpadding="4" cellspacing="0">
                      <!-- Add header row to force column widths. Prevents
                           stuff from moving all over the screen when showing/
                           hiding rows for different ISPs -->
                      <tr>
                        <th width="200px"/>
                        <th width="100px"/>
                        <th width="200px"/>
                      </tr>
                      <tr>
                        <td class="Label">
                          <pepper:textString package="{$packageId}" key="Settings.Personal.ISP"/>
                        </td>
                        <td colspan="2">
                          <select id="isp1" size="1" class="Field"
                                  nosavexpath="page/user/emailAccount[position()=1]/isp" 
                                  onchange="changeISP(this, this.options[selectedIndex].value, true)">
                            <!-- The 'ChooseISP' id is used by the javascript - don't change it -->
                            <option value="ChooseISP">
                              <pepper:textString package="{$packageId}" key="Settings.Personal.ChooseISP"/>
                            </option>
                            <xsl:variable name="ispSetting" select="isp" />

                              <xsl:variable name="providers" select="concat($platform,'/resources/xsl/MailProviders.xml')" />
                              <xsl:variable name="ISP" select="document($providers)/mailProviders/isp" />

                              <xsl:for-each select="$ISP">
                              <xsl:choose>
                                <xsl:when test="@id = $ispSetting">
                                  <option value="{@id}" selected="yes"><xsl:value-of select="@name"/></option>
                                </xsl:when>
                                <xsl:otherwise>
                                  <option value="{@id}"><xsl:value-of select="@name"/></option>
                                </xsl:otherwise>
                              </xsl:choose>
                            </xsl:for-each>
                            <!-- Add 'Other' ISP, select it if necessary -->
                            <!-- The 'Other' id is used by the javascript - don't change it -->
                            <xsl:choose>
                              <xsl:when test="isp = 'Other'"> 
                                <option value="Other" selected="yes">
                                  <pepper:textString package="{$packageId}" key="Settings.Personal.OtherISP"/>
                                </option>
                              </xsl:when>
                              <xsl:otherwise>
                                <option value="Other">
                                  <pepper:textString package="{$packageId}" key="Settings.Personal.OtherISP"/>
                                </option>
                              </xsl:otherwise>
                            </xsl:choose>
                          </select>
                        </td>
                      </tr>
                      <tr style="display:none" id="location1tr">
                        <td class="Label">
                          <pepper:textString package="{$packageId}" key="Settings.Personal.ISPLocation"/>
                        </td>
                        <td colspan="2">
                          <select id="location1" size="1" class="Field"
                                  nosavexpath="page/user/emailAccount[position()=1]/location" 
                                  onchange="selectLocation(this, this.options[selectedIndex].value)">
                            <option selected="selected" value="{location}">Dummy Location</option>
                          </select>
                        </td>
                      </tr>
                      <tr style="display:none" id="protocol1tr">
                        <td class="Label">
                          <pepper:textString package="{$packageId}" key="Settings.Personal.AccountType"/>
                        </td>
                        <td colspan="2">
                          <select id="protocol1" size="1" class="Field"
                                  nosavexpath="page/user/emailAccount[position()=1]/incomingServer/type" 
                                  onchange="setProtocol(this)">
                            <xsl:choose>
                              <xsl:when test="incomingServer/type = 'pop3'">
                                <option value="pop3" selected="yes">
                                  <pepper:textString package="{$packageId}" key="Settings.Personal.POP3Type"/>
                                </option>
                              </xsl:when>
                              <xsl:otherwise>
                                <option value="pop3">
                                  <pepper:textString package="{$packageId}" key="Settings.Personal.POP3Type"/>
                                </option>
                              </xsl:otherwise>
                            </xsl:choose>
                            <xsl:choose>
                              <xsl:when test="incomingServer/type = 'imap'">
                                <option value="imap" selected="yes">
                                   <pepper:textString package="{$packageId}" key="Settings.Personal.IMAPType"/>
                                </option>
                              </xsl:when>
                              <xsl:otherwise>
                                <option value="imap">
                                  <pepper:textString package="{$packageId}" key="Settings.Personal.IMAPType"/>
                                </option>
                              </xsl:otherwise>
                            </xsl:choose>
                          </select>
                        </td>
                      </tr>
                      <tr style="display:none" id="fullName1tr">
                        <td class="Label">
                          <pepper:textString package="{$packageId}" key="Settings.Personal.MailDisplayName"/>
                        </td>
                        <td class="Text">
                          <input type="text" class="Field" style="width:250px;" value="{fullName}" id="fullName1" 
                              nosavexpath="page/user/emailAccount[position()=1]/fullName" />
                        </td>
                        <td class="Text"><pepper:textString package="{$packageId}" key="Settings.Personal.MailDisplayNameExample"/></td>
                      </tr>
                      <tr style="display:none" id="mailAddress1tr">
                        <td class="Label">
                          <pepper:textString package="{$packageId}" key="Settings.Personal.EmailAddress"/>
                        </td>
                        <td class="Text">
                          <input type="text" class="Field" style="width:250px;" value="{mailAddress}" id="mailAddress1" 
                              nosavexpath="page/user/emailAccount[position()=1]/mailAddress" />
                        </td>
                        <td class="Text"><pepper:textString package="{$packageId}" key="Settings.Personal.EmailAddressExample"/></td>
                      </tr>
                      <tr style="display:none" id="username1tr">
                        <td class="Label" id="usernameLabel1">
                          <pepper:textString package="{$packageId}" key="Settings.Personal.MailUserName"/>
                        </td>
                        <td class="Text">
                          <input type="text" class="Field" style="width:250px;" value="{incomingServer/username}" id="username1" 
                              nosavexpath="page/user/emailAccount[position()=1]/incomingServer/username" />
                        </td>
                        <td class="Text"><pepper:textString package="{$packageId}" key="Settings.Personal.MailUserNameExample"/></td>
                      </tr>
                      <tr style="display:none" id="password1tr">
                        <td class="Label">
                          <pepper:textString package="{$packageId}" key="Settings.Personal.MailPassword"/>
                        </td>
                        <td class="Text">
                          <xsl:variable name="pwd" select="pepper:unroast(incomingServer/password)"/>
                          <input type="password" class="Field" style="width:250px;" value="{$pwd}" id="password1" 
                              nosavexpath="page/user/emailAccount[position()=1]/incomingServer/password" />
                        </td>
                        <td class="Text">
                            <input type="button" id="test" onClick="bridge.action('TestMailSettings');"
                                value="{pepper:textString($packageId, 'PageBar.TestMailSettings')}" />
                        </td>
                      </tr>
                      <tr style="display:none" id="incomingHost1tr">
                        <td class="Label">
                          <pepper:textString package="{$packageId}" key="Settings.Personal.IncomingMailHost"/>
                        </td>
                        <td class="Text">
                          <input type="text" class="Field" style="width:250px;" value="{incomingServer/host}" id="incomingHost1" 
                              nosavexpath="page/user/emailAccount[position()=1]/incomingServer/host" />
                        </td>
                        <td class="Text"><pepper:textString package="{$packageId}" key="Settings.Personal.IncomingMailHostExample"/></td>
                      </tr>
                      <tr style="display:none" id="incomingPort1tr">
                        <td class="Label">
                          <pepper:textString package="{$packageId}" key="Settings.Personal.IncomingMailPort"/>
                        </td>
                        <td>
                          <input type="text" class="Field" style="width:250px;" value="{incomingServer/port}" id="incomingPort1" 
                              nosavexpath="page/user/emailAccount[position()=1]/incomingServer/port" />
                        </td>
                        <td class="Text"><pepper:textString package="{$packageId}" key="Settings.Personal.IncomingMailPortExample"/></td>
                      </tr>
                      <tr style="display:none" id="outgoingHost1tr">
                        <td class="Label">
                          <pepper:textString package="{$packageId}" key="Settings.Personal.OutgoingHost"/>
                        </td>
                        <td class="Text">
                          <input type="text" class="Field" style="width:250px;" value="{outgoingServer/host}" id="outgoingHost1" 
                              nosavexpath="page/user/emailAccount[position()=1]/outgoingServer/host" />
                        </td>
                        <td class="Text"><pepper:textString package="{$packageId}" key="Settings.Personal.OutgoingHostExample"/></td>
                      </tr>
                      <tr style="display:none" id="outgoingPort1tr">
                        <td class="Label">
                          <pepper:textString package="{$packageId}" key="Settings.Personal.OutgoingPort"/>
                        </td>
                        <td class="Text">
                          <input type="text" class="Field" style="width:250px;" value="{outgoingServer/port}" id="outgoingPort1" 
                              nosavexpath="page/user/emailAccount[position()=1]/outgoingServer/port" />
                        </td>
                        <td class="Text"><pepper:textString package="{$packageId}" key="Settings.Personal.OutgoingPortExample"/></td>
                      </tr>
                      <tr style="display:none" id="outgoingAuth1tr">
                        <td class="Label">
                          <pepper:textString package="{$packageId}" key="Settings.Personal.OutgoingAuth"/>
                        </td>
                        <td class="Text" colspan="2">
                          <!-- Don't use pepper:checkbox, it only supports yes/no while we want none/password (and
                               someday other auth types, like DIGEST-MD5) -->
                          <select id="outgoingAuth1" size="1" class="Field"
                                  nosavexpath="page/user/emailAccount[position()=1]/outgoingServer/auth" >
                            <xsl:choose>
                              <xsl:when test="outgoingServer/auth = 'none'">
                                <option value="none" selected="yes">
                                  <pepper:textString package="{$packageId}" key="Settings.Personal.AuthNone"/>
                                </option>
                              </xsl:when>
                              <xsl:otherwise>
                                <option value="none">
                                  <pepper:textString package="{$packageId}" key="Settings.Personal.AuthNone"/>
                                </option>
                              </xsl:otherwise>
                            </xsl:choose>
                            <xsl:choose>
                              <xsl:when test="outgoingServer/auth = 'password'">
                                <option value="password" selected="yes">
                                   <pepper:textString package="{$packageId}" key="Settings.Personal.AuthPassword"/>
                                </option>
                              </xsl:when>
                              <xsl:otherwise>
                                <option value="password">
                                  <pepper:textString package="{$packageId}" key="Settings.Personal.AuthPassword"/>
                                </option>
                              </xsl:otherwise>
                            </xsl:choose>
                          </select>
                        </td>
                      </tr>
                      <tr>
                        <td class="Label">
                          <pepper:textString package="{$packageId}" key="Settings.Personal.LeaveOnServer"/>
                        </td>
                        <td class="Text" colspan="2">
                          <!-- leaveOnServer is a new addition; make sure it's checked if the data
                               didn't have the leaveOnServer element -->
                          <xsl:variable name="leaveOnServer">
                            <xsl:choose>
                              <xsl:when test="not(leaveOnServer)">true</xsl:when>
                              <xsl:otherwise>
                                <xsl:value-of select="leaveOnServer"/>
                              </xsl:otherwise>
                            </xsl:choose>
                          </xsl:variable>
                          <xsl:choose>
                            <xsl:when test="$leaveOnServer = 'true'">
                              <input type="checkbox" checked="true" class="Field" style="text-align: left" 
                                  id="leaveOnServer1" nosavexpath="page/user/emailAccount[position()=1]/leaveOnServer" />
                            </xsl:when>
                            <xsl:otherwise>
                              <input type="checkbox" class="Field" style="text-align: left" 
                                  id="leaveOnServer1" nosavexpath="page/user/emailAccount[position()=1]/leaveOnServer" />
                            </xsl:otherwise>
                          </xsl:choose>
                        </td>
                      </tr>
                    </table>
                  </td>
                </tr>
              </xsl:for-each>
            </table>
          </form>
	        <!-- Display some help text -->
	        <div class="SettingsHelp">
	        	<xsl:value-of select="pepper:textString($packageId,'Settings.Personal.Mail.Help')" 
	            	disable-output-escaping="yes"/>
			</div>
	        <!-- Display next page prompt for Setup Helper -->
	  		<xsl:if test="$setup = 'true'">
	        	<input type="button" onmouseup="bridge.action('NextPage');" class="NextPrompt"
	      			value="{pepper:textString($packageId, concat('Setup.Mail.NextPrompt.', $arch))}"/> 
			</xsl:if>
        </div>
        </div>
      </body>
    </html>
  </xsl:template>
</xsl:stylesheet>
