<?xml version="1.0" encoding="UTF-8"?>
<!--Standard Web section page stylesheet, (c) 2005 Pepper Computer, Inc. -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xalan="http://xml.apache.org/xalan"
    xmlns:pepper="http://www.pepper.com/elements" extension-element-prefixes="pepper">
    <xalan:component prefix="pepper">
        <xalan:script lang="javaclass" src="com.pepper.script.Elements"/>
    </xalan:component>
    <xsl:output method="xml" media-type="application/vnd.mozilla.xul+xml"
        doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN"
        doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"/>
    
    <xsl:param name="packageId"/>
    <xsl:param name="platform"/>
    <xsl:param name="dataDir"/>
    <xsl:param name="displayBookmarks" select="'false'"/>
    
    <xsl:template match="/">
        <xsl:text disable-output-escaping="yes">&lt;?xml-stylesheet href="chrome://global/skin/" type="text/css"?&gt;</xsl:text>
        <xsl:text disable-output-escaping="yes">&lt;?xml-stylesheet </xsl:text>href="<xsl:value-of select="$platform"/>/resources/styles/styles.css" type="text/css"<xsl:text disable-output-escaping="yes">?&gt;</xsl:text>
        
        <xsl:variable name="homepageURL" select="section/page[@homepage= 'true']/url"/>
        <xsl:variable name="homepageName" select="section/page[@homepage= 'true']/@name"/>
        <xsl:choose>
            <!-- If there is a homepage specified, automatically load it. -->
            <xsl:when test="$displayBookmarks = 'false' and $homepageURL != ''">
                <html xmlns="http://www.w3.org/1999/xhtml">
                    <head />
                    <body onload="window.location.replace('{$homepageURL}')">
                        <center>
                            <div style="margin-top:100px; color:black; font-size:16px; font-family:sans-serif;">
                                Loading <xsl:value-of select="$homepageName"/>
                            </div>
                        </center>
                    </body>
                </html>
            </xsl:when>
            <!-- Otherwise display the list of bookmarks, clippings and history -->
            <xsl:otherwise>
                <window xmlns="http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul"
                    title="{pepper:nameString($packageId, section/@name)}">
                    <script type="text/javascript" src="{$platform}/resources/commonsection.js"/>
                    <script type="text/javascript" src="{$platform}/resources/xsl/web.js"/>
                    <pepper:initscriptbridge package="{$packageId}" oninit="initPage('contenttree');"/>
                    <!-- Display the page bar -->
                    <pepper:pagebar class="PageBar" id="pb-{$packageId}" package="{$packageId}">
                        <pepper:pagebarentry key="PageBar.Open" script="showURL(null)"/>
                        <pepper:pagebarentry key="PageBar.AddBookmark" script="addBookmark()"/>
                        <pepper:pagebarentry key="PageBar.EditBookmark" script="editBookmark()"/>
                        <xsl:if test="starts-with($packageId, 'Web')">
                            <pepper:pagebarentry key="PageBar.Sync" action="Sync"/>
                        </xsl:if>
                        <pepper:pagebarentry key="PageBar.DeleteEntry" script="deleteFromWeb()"/>
                        <pepper:pagebarentry key="PageBar.ClearTabHistoryEntry" script="clearHistory()"/>
                    </pepper:pagebar>
                    
                    <!-- Display the section page contents as a tree containing the bookmarks, clippings and history entries -->
                    <box flex="1" class="PageContent">
                        <tree class="Content" flex="1" hidecolumnpicker="true" id="contenttree"
                            onkeydown="if (event.keyCode == KeyEvent.DOM_VK_RETURN) showURL(event); 
                                        if (event.keyCode == KeyEvent.DOM_VK_BACK_SPACE) deletePage();"
                            onkeypress="handleKeypress(event, this);" ondblclick="showURL(event);">
                            <treecols>
                                <treecol class="Content" width="20" id="homepageIcon" persist="width ordinal"/>
                                
                                <treecol flex="1" label="Title" id="name" class="Content" primary="true" persist="width"/>
                                <splitter class="tree-splitter"/>
                                <treecol flex="2" label="Address" id="url" class="Content" persist="width"/>
                            </treecols>
                            <treechildren>
                                <!-- Display the bookmarks -->
                                <treeitem container="true" open="true">
                                    <treerow>
                                        <treecell label=""/>
                                        <treecell label="Bookmarks" properties="heading"/>
                                    </treerow>
                                    <treechildren>
                                        <xsl:for-each select="section/page[@type='web-bookmark']">
                                            <xsl:sort select="@homepage = 'true'" order="descending"/>
                                            <xsl:sort select="@name" order="ascending"/>
                                            <treeitem id="{@id}" type="bookmark">
                                                <treerow>
                                                    
                                                    <xsl:choose>
                                                        <xsl:when test="@homepage = 'true'">
                                                            <treecell src="{$platform}/resources/icons/home16.gif" value="{@id}"/>
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            <treecell value="{@id}"/>
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                    
                                                    <treecell label="{@name}"/>
                                                    <treecell label="{url}" value="{url}"/>
                                                </treerow>
                                            </treeitem>
                                        </xsl:for-each>
                                    </treechildren>
                                </treeitem>
                                <!-- Display the clippings -->
                                <treeitem container="true" open="true">
                                    <treerow>
                                        <treecell label=""/>
                                        <treecell label="Clippings" properties="heading"/>
                                    </treerow>
                                    <treechildren>
                                        <xsl:for-each select="section/page[@type='web-clipping']">
                                            <treeitem id="{@id}">
                                                <treerow>
                                                    <treecell label=""/>
                                                    <treecell label="{@name}"/>
                                                    <treecell label="{url}" value="{$dataDir}/{htmlFile}"/>
                                                </treerow>
                                            </treeitem>
                                        </xsl:for-each>
                                    </treechildren>
                                </treeitem>
                                <!-- Display the history -->
                                <treeitem container="true" open="false">
                                    <treerow>
                                        <treecell label=""/>
                                        <treecell label="History" properties="heading"/>
                                    </treerow>
                                    <!-- NOTE: don't change this id as it's used by clearHistory() -->
                                    <treechildren id='historychildren'>
                                        <!-- Loop through Web session history date elements -->
                                        <xsl:for-each select="section/webSession">
                                            <xsl:variable name="sessionDate" select="@id"/>
                                            <treeitem container="true" open="true" id="/{$sessionDate}">
                                                <treerow>
                                                    <treecell label=""/>
                                                    <treecell label="{$sessionDate}" properties="subheading"/>
                                                </treerow>
                                                <treechildren>
                                                    <!--Loop through the host elements within the date -->
                                                    <xsl:for-each select="host">
                                                        <xsl:variable name="sessionHost" select="@id"/>
                                                        <treeitem container="true" open="true" id="/{$sessionDate}/{$sessionHost}">
                                                            <treerow>
                                                                <treecell label=""/>
                                                                <treecell label="{@id}" properties="subheading"/>
                                                            </treerow>
                                                            <treechildren>
                                                                
                                                                <!-- Loop through the session elements within the host -->
                                                                <xsl:for-each select="sessionEntry">
                                                                    <treeitem id="/{$sessionDate}/{$sessionHost}/{@id}">
                                                                        <treerow>
                                                                            <treecell label=""/>
                                                                            <treecell label="{title}"/>
                                                                            <treecell label="{url}" value="{url}"/>
                                                                        </treerow>
                                                                    </treeitem>
                                                                </xsl:for-each>
                                                            </treechildren>
                                                        </treeitem>
                                                    </xsl:for-each>
                                                </treechildren>
                                            </treeitem>
                                        </xsl:for-each>
                                    </treechildren>
                                </treeitem>
                            </treechildren>
                        </tree>
                    </box>
                </window>
            </xsl:otherwise>
        </xsl:choose> </xsl:template>
</xsl:stylesheet>